@@ -5,8 +5,8 @@
 #include "communicator.h"
 
 std::unique_ptr<Communicator> getCommunicator(const bool printProgress) {
-  // if (printProgress) {
-  //   return std::unique_ptr<Communicator>(new PrintCommunicator());
-  // }
-  return nullptr;
+    if (printProgress) {
+        return std::unique_ptr<Communicator>(new ProgressCommunicator(printProgress));
+    }
+    return nullptr;
 }
