@@ -8,17 +8,13 @@
 
 #include "agentanalysis.h"
 
-Agent::Agent(AgentProgram *program, PointMap *pointmap, int output_mode) {
-    m_program = program;
-    m_pointmap = pointmap;
-    m_output_mode = output_mode;
-    m_trail_num = -1;
-}
+Agent::Agent(AgentProgram *program, PointMap *pointmap, int outputMode)
+    : m_program(program), m_pointmap(pointmap), m_outputMode(outputMode), m_trailNum(-1) {}
 
-void Agent::onInit(PixelRef node, int trail_num) {
+void Agent::onInit(PixelRef node, int trailNum) {
     m_node = node;
     m_loc = m_pointmap->depixelate(m_node);
-    if (m_output_mode & OUTPUT_GATE_COUNTS) {
+    if (m_outputMode & OUTPUT_GATE_COUNTS) {
         // see note about gates in Through vision analysis
         m_gate = (m_pointmap->getPoint(node).filled())
                      ? (int)m_pointmap->getAttributeTable()
@@ -28,44 +24,44 @@ void Agent::onInit(PixelRef node, int trail_num) {
     } else {
         m_gate = -1;
     }
-    m_gate_encountered = false;
+    m_gateEncountered = false;
     m_step = 0;
     m_stuck = false;
     m_stopped = false;
     m_frame = 0;
-    m_target_lock = false;
+    m_targetLock = false;
     m_vector = Point2f(1, 0);
 
-    m_at_target = false;
-    m_at_destination = false;
+    m_atTarget = false;
+    m_atDestination = false;
 
-    m_trail_num = trail_num;
+    m_trailNum = trailNum;
 
     m_vector = onLook(true);
 
     m_vector.normalise();
 
-    m_target_pix = NoPixel;
+    m_targetPix = NoPixel;
 }
 
 void Agent::onMove() {
-    m_at_target = false;
+    m_atTarget = false;
     m_frame++;
-    if (m_program->m_destination_directed && dist(m_loc, m_destination) < 10.0) {
+    if (m_program->destinationDirected && dist(m_loc, m_destination) < 10.0) {
         // reached final destination
         onDestination();
-    } else if ((m_program->m_sel_type & AgentProgram::SEL_TARGETTED) &&
+    } else if ((m_program->selType & AgentProgram::SEL_TARGETTED) &&
                dist(m_loc, m_target) < m_pointmap->getSpacing()) {
         // reached target (intermediate destination)
         m_step = 0;
         onTarget();
         m_vector = onLook(false);
-    } else if (pafmath::prandomr() < (1.0 / m_program->m_steps) &&
-               !m_target_lock) { // note, on average, will change 1 in steps
+    } else if (pafmath::prandomr() < (1.0 / m_program->steps) &&
+               !m_targetLock) { // note, on average, will change 1 in steps
         m_step = 0;
         m_vector = onLook(false);
         /*
-        if (m_program->m_destination_directed) {
+        if (m_program->destinationDirected) {
            Point2f vec2 = m_destination - m_loc;
            vec2.normalise();
            if (dot(vec2,m_vector) < 0.0) {
@@ -81,20 +77,20 @@ void Agent::onMove() {
     // now step...
     PixelRef lastnode = m_node;
     onStep();
-    if (m_node != lastnode && m_output_mode != OUTPUT_NOTHING) {
+    if (m_node != lastnode && m_outputMode != OUTPUT_NOTHING) {
         if (m_pointmap->getPoint(m_node).filled()) {
             AttributeRow &row = m_pointmap->getAttributeTable().getRow(AttributeKey(m_node));
-            if (m_output_mode & OUTPUT_COUNTS) {
+            if (m_outputMode & OUTPUT_COUNTS) {
                 row.incrValue(AgentAnalysis::Column::GATE_COUNTS);
             }
-            if (m_output_mode & OUTPUT_GATE_COUNTS) {
+            if (m_outputMode & OUTPUT_GATE_COUNTS) {
                 int obj = (int)row.getValue(AgentAnalysis::Column::INTERNAL_GATE);
                 if (m_gate != obj) {
                     m_gate = obj;
                     if (m_gate != -1) {
                         row.incrValue(AgentAnalysis::Column::INTERNAL_GATE_COUNTS);
                         // actually crossed into a new gate:
-                        m_gate_encountered = true;
+                        m_gateEncountered = true;
                     }
                 }
             }
@@ -102,10 +98,10 @@ void Agent::onMove() {
     }
     // done. happy hamster.
 }
-void Agent::onDestination() { m_at_destination = true; }
+void Agent::onDestination() { m_atDestination = true; }
 void Agent::onTarget() {
-    m_occ_memory.a().clear();
-    m_at_target = true;
+    m_occMemory.a().clear();
+    m_atTarget = true;
 }
 
 ////////////////////////////////////////////////////////////////////
@@ -132,8 +128,8 @@ void Agent::onStep() {
     } else {
         m_loc = nextloc;
     }
-    if (!m_stopped && m_trail_num != -1) {
-        m_program->m_trails[m_trail_num].push_back(Event2f(m_loc, m_program->m_steps));
+    if (!m_stopped && m_trailNum != -1) {
+        m_program->trails[m_trailNum].push_back(Event2f(m_loc, m_program->steps));
     }
 }
 bool Agent::diagonalStep() {
@@ -197,22 +193,21 @@ bool Agent::goodStep(PixelRef node) {
 
 Point2f Agent::onLook(bool wholeisovist) {
     Point2f dir;
-    if (m_program->m_sel_type & AgentProgram::SEL_GIBSONIAN) {
+    if (m_program->selType & AgentProgram::SEL_GIBSONIAN) {
         dir = onGibsonianLook(wholeisovist);
-    } else if ((m_program->m_sel_type & AgentProgram::SEL_OCCLUSION) ==
-               AgentProgram::SEL_OCCLUSION) {
-        dir = onOcclusionLook(wholeisovist, m_program->m_sel_type);
+    } else if ((m_program->selType & AgentProgram::SEL_OCCLUSION) == AgentProgram::SEL_OCCLUSION) {
+        dir = onOcclusionLook(wholeisovist, m_program->selType);
     } else {
-        switch (m_program->m_sel_type) {
+        switch (m_program->selType) {
         case AgentProgram::SEL_STANDARD:
             dir = onStandardLook(wholeisovist);
             break;
         case AgentProgram::SEL_LOS:
         case AgentProgram::SEL_LOS_OCC:
-            if (m_program->m_destination_directed) {
-                dir = onDirectedLoSLook(wholeisovist, m_program->m_sel_type);
+            if (m_program->destinationDirected) {
+                dir = onDirectedLoSLook(wholeisovist, m_program->selType);
             } else {
-                dir = onLoSLook(wholeisovist, m_program->m_sel_type);
+                dir = onLoSLook(wholeisovist, m_program->selType);
             }
             break;
         case AgentProgram::SEL_OPTIC_FLOW2:
@@ -220,11 +215,11 @@ Point2f Agent::onLook(bool wholeisovist) {
             break;
         }
     }
-    if ((m_program->m_sel_type & AgentProgram::SEL_GIBSONIAN) && !m_stuck) {
+    if ((m_program->selType & AgentProgram::SEL_GIBSONIAN) && !m_stuck) {
         // remember what the view looked like here, facing our new direction:
         calcLoS(binfromvec(dir), false);
     }
-    if ((m_program->m_sel_type & AgentProgram::SEL_GIBSONIAN2) && !m_stuck) {
+    if ((m_program->selType & AgentProgram::SEL_GIBSONIAN2) && !m_stuck) {
         calcLoS2(binfromvec(dir), false);
     }
 
@@ -233,7 +228,7 @@ Point2f Agent::onLook(bool wholeisovist) {
 
 Point2f Agent::onStandardLook(bool wholeisovist) {
     int tarpixelate = -1;
-    int vbin = m_program->m_vbin;
+    int vbin = m_program->vbin;
     if (wholeisovist || vbin == -1) {
         vbin = 16;
     }
@@ -253,7 +248,7 @@ Point2f Agent::onStandardLook(bool wholeisovist) {
         } else {
             m_stuck = true;
             m_target = m_loc;
-            m_target_pix = m_node;
+            m_targetPix = m_node;
             return Point2f(0, 0);
         }
     } else {
@@ -271,7 +266,7 @@ Point2f Agent::onStandardLook(bool wholeisovist) {
         }
     }
 
-    m_target_pix = tarpixelate;
+    m_targetPix = tarpixelate;
     m_target = m_pointmap->depixelate(tarpixelate);
 
     return (m_target - m_loc).normalise();
@@ -284,7 +279,7 @@ Point2f Agent::onWeightedLook(bool wholeisovist) {
         return onStandardLook(true);
     }
     int tarpixelate = -1;
-    int vbin = m_program->m_vbin;
+    int vbin = m_program->vbin;
     if (vbin == -1) {
         vbin = 16;
     }
@@ -331,7 +326,7 @@ Point2f Agent::onWeightedLook(bool wholeisovist) {
         }
     }
 
-    m_target_pix = tarpixelate;
+    m_targetPix = tarpixelate;
     m_target = m_pointmap->depixelate(tarpixelate);
 
     return (m_target - m_loc).normalise();
@@ -339,8 +334,8 @@ Point2f Agent::onWeightedLook(bool wholeisovist) {
 
 Point2f Agent::onOcclusionLook(bool wholeisovist, int looktype) {
     if (looktype == AgentProgram::SEL_OCC_MEMORY) {
-        m_occ_memory.flip();
-        m_occ_memory.a().clear();
+        m_occMemory.flip();
+        m_occMemory.a().clear();
     }
 
     if (wholeisovist) {
@@ -348,7 +343,7 @@ Point2f Agent::onOcclusionLook(bool wholeisovist, int looktype) {
         return onStandardLook(true);
     }
     PixelRef tarpixelate = NoPixel;
-    int vbin = m_program->m_vbin;
+    int vbin = m_program->vbin;
     if (vbin == -1) {
         vbin = 16;
     }
@@ -362,8 +357,8 @@ Point2f Agent::onOcclusionLook(bool wholeisovist, int looktype) {
         int choices = 0;
         Node &node = m_pointmap->getPoint(m_node).getNode();
         for (int i = 0; i < vbin; i++) {
-            if (node.m_occlusion_bins[(directionbin + i) % 32].size()) {
-                choices += node.m_occlusion_bins[(directionbin + i) % 32].size();
+            if (node.occlusionBins[(directionbin + i) % 32].size()) {
+                choices += node.occlusionBins[(directionbin + i) % 32].size();
             }
         }
         if (choices == 0) {
@@ -371,16 +366,16 @@ Point2f Agent::onOcclusionLook(bool wholeisovist, int looktype) {
                 return onStandardLook(false);
             } else {
                 m_stuck = true;
-                m_target_pix = m_node;
+                m_targetPix = m_node;
                 m_target = m_loc;
                 return Point2f(0, 0);
             }
         } else {
             size_t chosen = pafmath::pafrand() % choices;
-            for (; chosen >= node.m_occlusion_bins[directionbin % 32].size(); directionbin++) {
-                chosen -= node.m_occlusion_bins[directionbin % 32].size();
+            for (; chosen >= node.occlusionBins[directionbin % 32].size(); directionbin++) {
+                chosen -= node.occlusionBins[directionbin % 32].size();
             }
-            tarpixelate = node.m_occlusion_bins[directionbin % 32].at(chosen);
+            tarpixelate = node.occlusionBins[directionbin % 32].at(chosen);
         }
     } else {
         int subset = 1;
@@ -396,9 +391,9 @@ Point2f Agent::onOcclusionLook(bool wholeisovist, int looktype) {
             PixelRef nigpix;
             double fardist = -1.0;
             for (int k = 0; k < subset; k++) {
-                for (size_t j = 0; j < node.m_occlusion_bins[(directionbin + i + k) % 32].size();
+                for (size_t j = 0; j < node.occlusionBins[(directionbin + i + k) % 32].size();
                      j++) {
-                    PixelRef pix = node.m_occlusion_bins[(directionbin + i + k) % 32].at(j);
+                    PixelRef pix = node.occlusionBins[(directionbin + i + k) % 32].at(j);
                     if (dist(pix, m_node) > fardist) {
                         fardist = dist(pix, m_node);
                         nigpix = pix;
@@ -408,10 +403,10 @@ Point2f Agent::onOcclusionLook(bool wholeisovist, int looktype) {
             if (fardist != -1.0) {
                 bool cont = true;
                 if (looktype == AgentProgram::SEL_OCC_MEMORY) {
-                    depthmapX::addIfNotExists(m_occ_memory.a(), nigpix);
+                    depthmapX::addIfNotExists(m_occMemory.a(), nigpix);
                     // the turn chance (pafrand() % 2) may have to be modified later...
-                    if (!m_at_target && std::find(m_occ_memory.b().begin(), m_occ_memory.b().end(),
-                                                  nigpix) != m_occ_memory.b().end()) {
+                    if (!m_atTarget && std::find(m_occMemory.b().begin(), m_occMemory.b().end(),
+                                                 nigpix) != m_occMemory.b().end()) {
                         cont = false;
                     }
                 }
@@ -453,7 +448,7 @@ Point2f Agent::onOcclusionLook(bool wholeisovist, int looktype) {
         }
     }
 
-    m_target_pix = tarpixelate;
+    m_targetPix = tarpixelate;
     m_target = m_pointmap->depixelate(tarpixelate);
 
     return (m_target - m_loc).normalise();
@@ -461,15 +456,15 @@ Point2f Agent::onOcclusionLook(bool wholeisovist, int looktype) {
 
 // note: LOS look uses similar weighted choice mechanism
 
-Point2f Agent::onLoSLook(bool wholeisovist, int look_type) {
+Point2f Agent::onLoSLook(bool wholeisovist, int lookType) {
     int bbin = -1;
-    if (m_program->m_destination_directed) {
+    if (m_program->destinationDirected) {
         Point2f vec2 = m_destination - m_loc;
         vec2.normalise();
         bbin = binfromvec(vec2);
     }
     int targetbin = -1;
-    int vbin = m_program->m_vbin;
+    int vbin = m_program->vbin;
     if (wholeisovist || vbin == -1) {
         vbin = 16;
     }
@@ -483,13 +478,13 @@ Point2f Agent::onLoSLook(bool wholeisovist, int look_type) {
     }
     for (int i = 0; i < vbin; i++) {
         double los =
-            (look_type == AgentProgram::SEL_LOS)
+            (lookType == AgentProgram::SEL_LOS)
                 ? m_pointmap->getPoint(m_node).getNode().bindistance((directionbin + i) % 32)
                 : m_pointmap->getPoint(m_node).getNode().occdistance((directionbin + i) % 32);
-        if (m_program->m_los_sqrd) {
+        if (m_program->losSqrd) {
             los *= los;
         }
-        if (m_program->m_destination_directed) {
+        if (m_program->destinationDirected) {
             los *= 1.0 - double(binsbetween(((directionbin + i) % 32), bbin)) / 16.0;
         }
         weight += los;
@@ -497,7 +492,7 @@ Point2f Agent::onLoSLook(bool wholeisovist, int look_type) {
     }
     if (weight == 0.0) {
         if (!wholeisovist) {
-            return onLoSLook(true, look_type);
+            return onLoSLook(true, lookType);
         } else {
             // oops!
             m_stuck = true;
@@ -518,11 +513,11 @@ Point2f Agent::onLoSLook(bool wholeisovist, int look_type) {
     return Point2f(cosf(angle), sinf(angle));
 }
 
-Point2f Agent::onDirectedLoSLook(bool wholeisovist, int look_type) {
+Point2f Agent::onDirectedLoSLook(bool wholeisovist, int lookType) {
     Point2f vec2 = m_destination - m_loc;
     vec2.normalise();
     int targetbin = -1;
-    int vbin = m_program->m_vbin;
+    int vbin = m_program->vbin;
     if (wholeisovist || vbin == -1) {
         vbin = 16;
     }
@@ -536,10 +531,10 @@ Point2f Agent::onDirectedLoSLook(bool wholeisovist, int look_type) {
     }
     for (int i = 0; i < vbin; i++) {
         double los =
-            (look_type == AgentProgram::SEL_LOS)
+            (lookType == AgentProgram::SEL_LOS)
                 ? m_pointmap->getPoint(m_node).getNode().bindistance((directionbin + i) % 32)
                 : m_pointmap->getPoint(m_node).getNode().occdistance((directionbin + i) % 32);
-        if (m_program->m_los_sqrd) {
+        if (m_program->losSqrd) {
             los *= los;
         }
         weight += los;
@@ -547,7 +542,7 @@ Point2f Agent::onDirectedLoSLook(bool wholeisovist, int look_type) {
     }
     if (weight == 0.0) {
         if (!wholeisovist) {
-            return onLoSLook(true, look_type);
+            return onLoSLook(true, lookType);
         } else {
             // oops!
             m_stuck = true;
@@ -579,82 +574,79 @@ Point2f Agent::onGibsonianLook(bool wholeisovist) {
     //
     calcLoS(binfromvec(m_vector), true);
     // now, choose action according to type of agent:
-    int rule_choice = -1;
+    int ruleChoice = -1;
     int dir = 0;
     for (int k = 0; k < 4; k++) {
-        dir = onGibsonianRule(m_program->m_rule_order[k]);
+        dir = onGibsonianRule(m_program->ruleOrder[k]);
         if (dir != 0) {
-            rule_choice = m_program->m_rule_order[k];
+            ruleChoice = m_program->ruleOrder[k];
             break;
         }
     }
 
     float angle = 0.0;
 
-    if (rule_choice != -1) {
-        angle =
-            (float)anglefrombin2((binfromvec(m_vector) + (2 * rule_choice + 1) * dir + 32) % 32);
+    if (ruleChoice != -1) {
+        angle = (float)anglefrombin2((binfromvec(m_vector) + (2 * ruleChoice + 1) * dir + 32) % 32);
     }
 
     // if no rule selection made, carry on in current direction
-    return (rule_choice == -1) ? m_vector : Point2f(cosf(angle), sinf(angle));
+    return (ruleChoice == -1) ? m_vector : Point2f(cosf(angle), sinf(angle));
 }
 
 int Agent::onGibsonianRule(int rule) {
     int option = 0;
-    switch (m_program->m_sel_type) {
+    switch (m_program->selType) {
     case AgentProgram::SEL_LENGTH:
         // rule_threshold from 0 to 100m
-        if (m_curr_los[rule + 1] > m_program->m_rule_threshold[rule]) {
+        if (m_currLos[rule + 1] > m_program->ruleThreshold[rule]) {
             option = 0x01;
         }
-        if (m_curr_los[rule + 5] > m_program->m_rule_threshold[rule]) {
+        if (m_currLos[rule + 5] > m_program->ruleThreshold[rule]) {
             option |= 0x10;
         }
         break;
     case AgentProgram::SEL_OPTIC_FLOW:
         // rule_threshold reflects from 0x (0) to 5x (100.0)
-        if ((m_curr_los[rule + 1] + 1) / (m_last_los[rule + 1] + 1) >
-            m_program->m_rule_threshold[rule] / 20.0) {
+        if ((m_currLos[rule + 1] + 1) / (m_lastLos[rule + 1] + 1) >
+            m_program->ruleThreshold[rule] / 20.0) {
             option = 0x01;
         }
-        if ((m_curr_los[rule + 5] + 1) / (m_last_los[rule + 5] + 1) >
-            m_program->m_rule_threshold[rule] / 20.0) {
+        if ((m_currLos[rule + 5] + 1) / (m_lastLos[rule + 5] + 1) >
+            m_program->ruleThreshold[rule] / 20.0) {
             option |= 0x10;
         }
         break;
     case AgentProgram::SEL_COMPARATIVE_LENGTH:
         // rule_threshold reflects from 0x (0) to 10x (100.0)
-        if ((m_curr_los[rule + 1] + 1) / (m_curr_los[0] + 1) >
-            m_program->m_rule_threshold[rule] / 10.0) {
+        if ((m_currLos[rule + 1] + 1) / (m_currLos[0] + 1) >
+            m_program->ruleThreshold[rule] / 10.0) {
             option = 0x01;
         }
-        if ((m_curr_los[rule + 5] + 1) / (m_curr_los[0] + 1) >
-            m_program->m_rule_threshold[rule] / 10.0) {
+        if ((m_currLos[rule + 5] + 1) / (m_currLos[0] + 1) >
+            m_program->ruleThreshold[rule] / 10.0) {
             option |= 0x10;
         }
         break;
     case AgentProgram::SEL_COMPARATIVE_OPTIC_FLOW:
         // rule_threshold reflects from 0x (0) to 10x (100.0)
-        if ((m_curr_los[rule + 1] * m_last_los[0] + 1) /
-                (m_last_los[rule + 1] * m_curr_los[0] + 1) >
-            m_program->m_rule_threshold[rule] / 10.0) {
+        if ((m_currLos[rule + 1] * m_lastLos[0] + 1) / (m_lastLos[rule + 1] * m_currLos[0] + 1) >
+            m_program->ruleThreshold[rule] / 10.0) {
             option = 0x01;
         }
-        if ((m_curr_los[rule + 5] * m_last_los[0] + 1) /
-                (m_last_los[rule + 5] * m_curr_los[0] + 1) >
-            m_program->m_rule_threshold[rule] / 10.0) {
+        if ((m_currLos[rule + 5] * m_lastLos[0] + 1) / (m_lastLos[rule + 5] * m_currLos[0] + 1) >
+            m_program->ruleThreshold[rule] / 10.0) {
             option |= 0x10;
         }
         break;
     }
     int dir = 0;
-    if (option == 0x01 && m_program->m_rule_probability[0] > pafmath::prandomr()) {
+    if (option == 0x01 && m_program->ruleProbability[0] > pafmath::prandomr()) {
         dir = -1;
-    } else if (option == 0x10 && m_program->m_rule_probability[0] > pafmath::prandomr()) {
+    } else if (option == 0x10 && m_program->ruleProbability[0] > pafmath::prandomr()) {
         dir = +1;
     } else if (option == 0x11 &&
-               m_program->m_rule_probability[0] > pafmath::prandomr() * pafmath::prandomr()) {
+               m_program->ruleProbability[0] > pafmath::prandomr() * pafmath::prandomr()) {
         // note, use random * random event as there are two ways to do this
         dir = (rand() % 2) ? -1 : +1;
     }
@@ -671,38 +663,38 @@ Point2f Agent::onGibsonianLook2(bool wholeisovist) {
     int maxbin = 0;
     /*
     // first action: adjust to longest line of sight
-    if (m_curr_los[3] > m_curr_los[0]) {
+    if (m_currLos[3] > m_currLos[0]) {
        maxbin = -m_program->m_vahead;
-       if (m_curr_los[4] > m_curr_los[0] && (pafrand() % 2)) {
+       if (m_currLos[4] > m_currLos[0] && (pafrand() % 2)) {
           maxbin = m_program->m_vahead;
        }
     }
-    else if (m_curr_los[4] > m_curr_los[0]) {
+    else if (m_currLos[4] > m_currLos[0]) {
        maxbin = m_program->m_vahead;
     }
     */
     // second action, apply feeler rule:
     char dir = 0x00;
-    if ((m_curr_los[1] - m_last_los[1]) / m_curr_los[1] > m_program->m_feeler_threshold) {
+    if ((m_currLos[1] - m_lastLos[1]) / m_currLos[1] > m_program->feelerThreshold) {
         dir |= 0x01;
     }
-    if ((m_curr_los[2] - m_last_los[2]) / m_curr_los[2] > m_program->m_feeler_threshold) {
+    if ((m_currLos[2] - m_lastLos[2]) / m_currLos[2] > m_program->feelerThreshold) {
         dir |= 0x10;
     }
-    if (dir == 0x01 && m_program->m_feeler_probability > pafmath::prandomr()) {
-        maxbin = -m_program->m_vbin;
-    } else if (dir == 0x10 && m_program->m_feeler_probability > pafmath::prandomr()) {
-        maxbin = m_program->m_vbin;
+    if (dir == 0x01 && m_program->feelerProbability > pafmath::prandomr()) {
+        maxbin = -m_program->vbin;
+    } else if (dir == 0x10 && m_program->feelerProbability > pafmath::prandomr()) {
+        maxbin = m_program->vbin;
     } else if (dir == 0x11 &&
-               m_program->m_feeler_probability > pafmath::prandomr() * pafmath::prandomr()) {
-        maxbin = (pafmath::pafrand() % 2) ? m_program->m_vbin : -m_program->m_vbin;
+               m_program->feelerProbability > pafmath::prandomr() * pafmath::prandomr()) {
+        maxbin = (pafmath::pafrand() % 2) ? m_program->vbin : -m_program->vbin;
     }
     // third action: detect heading for dead-end
-    if (maxbin == 0 && (m_curr_los[0] / m_pointmap->getSpacing() < m_program->m_ahead_threshold)) {
-        if (m_curr_los[1] >= m_curr_los[2]) {
-            maxbin = -m_program->m_vbin;
+    if (maxbin == 0 && (m_currLos[0] / m_pointmap->getSpacing() < m_program->aheadThreshold)) {
+        if (m_currLos[1] >= m_currLos[2]) {
+            maxbin = -m_program->vbin;
         } else {
-            maxbin = m_program->m_vbin;
+            maxbin = m_program->vbin;
         }
     }
 
@@ -715,9 +707,9 @@ Point2f Agent::onGibsonianLook2(bool wholeisovist) {
 void Agent::calcLoS(int directionbin, bool curr) {
     float *los;
     if (curr) {
-        los = m_curr_los;
+        los = m_currLos;
     } else {
-        los = m_last_los;
+        los = m_lastLos;
     }
     Node &node = m_pointmap->getPoint(m_node).getNode();
     // ahead
@@ -737,17 +729,17 @@ void Agent::calcLoS(int directionbin, bool curr) {
 void Agent::calcLoS2(int directionbin, bool curr) {
     float *los;
     if (curr) {
-        los = m_curr_los;
+        los = m_currLos;
     } else {
-        los = m_last_los;
+        los = m_lastLos;
     }
     Node &node = m_pointmap->getPoint(m_node).getNode();
     // ahead
     los[0] = node.bindistance(directionbin % 32);
     // directions:
-    los[1] = node.bindistance((directionbin - m_program->m_vbin + 32) % 32);
-    los[2] = node.bindistance((directionbin + m_program->m_vbin) % 32);
+    los[1] = node.bindistance((directionbin - m_program->vbin + 32) % 32);
+    los[2] = node.bindistance((directionbin + m_program->vbin) % 32);
     //
-    los[3] = node.bindistance((directionbin - m_program->m_vahead + 32) % 32);
-    los[4] = node.bindistance((directionbin + m_program->m_vahead) % 32);
+    los[3] = node.bindistance((directionbin - m_program->vahead + 32) % 32);
+    los[4] = node.bindistance((directionbin + m_program->vahead) % 32);
 }
