@@ -26,55 +26,64 @@ void AttributeColumnImpl::setFormula(std::string newFormula) { m_formula = newFo
 
 const std::string &AttributeColumnImpl::getFormula() const { return m_formula; }
 
-const AttributeColumnStats &AttributeColumnImpl::getStats() const { return m_stats; }
+const AttributeColumnStats &AttributeColumnImpl::getStats() const { return stats; }
 
 void AttributeColumnImpl::updateStats(float val, float oldVal) const {
-    if (m_stats.total < 0) {
-        m_stats.total = val;
+    if (stats.total < 0) {
+        stats.total = val;
     } else {
-        m_stats.total += val;
-        m_stats.total -= oldVal;
+        stats.total += val;
+        stats.total -= oldVal;
     }
-    if (val > m_stats.max) {
-        m_stats.max = val;
+    if (val > stats.max) {
+        stats.max = val;
     }
-    if (m_stats.min < 0 || val < m_stats.min) {
-        m_stats.min = val;
+    if (stats.min < 0 || val < stats.min) {
+        stats.min = val;
     }
 }
 
+void AttributeColumnImpl::setStats(const AttributeColumnStats &otherSats) const {
+    stats.max = otherSats.max;
+    stats.min = otherSats.min;
+    stats.total = otherSats.total;
+    stats.visibleTotal = otherSats.visibleTotal;
+    stats.visibleMax = otherSats.visibleMax;
+    stats.visibleMin = otherSats.visibleMin;
+}
+
 void AttributeColumnImpl::setName(const std::string &name) { m_name = name; }
 
 size_t AttributeColumnImpl::read(std::istream &stream) {
     m_name = dXstring::readString(stream);
     float val;
-    stream.read((char *)&val, sizeof(float));
-    m_stats.min = val;
-    stream.read((char *)&val, sizeof(float));
-    m_stats.max = val;
-    stream.read((char *)&m_stats.total, sizeof(double));
-    int physical_column;
-    stream.read((char *)&physical_column,
+    stream.read(reinterpret_cast<char *>(&val), sizeof(float));
+    stats.min = val;
+    stream.read(reinterpret_cast<char *>(&val), sizeof(float));
+    stats.max = val;
+    stream.read(reinterpret_cast<char *>(&stats.total), sizeof(double));
+    int physicalColumn;
+    stream.read(reinterpret_cast<char *>(&physicalColumn),
                 sizeof(int)); // physical column is obsolete
-    stream.read((char *)&m_hidden, sizeof(bool));
-    stream.read((char *)&m_locked, sizeof(bool));
+    stream.read(reinterpret_cast<char *>(&m_hidden), sizeof(bool));
+    stream.read(reinterpret_cast<char *>(&m_locked), sizeof(bool));
 
-    stream.read((char *)&m_displayParams, sizeof(DisplayParams));
+    stream.read(reinterpret_cast<char *>(&m_displayParams), sizeof(DisplayParams));
     m_formula = dXstring::readString(stream);
-    return static_cast<size_t>(physical_column);
+    return static_cast<size_t>(physicalColumn);
 }
 
 void AttributeColumnImpl::write(std::ostream &stream, int physicalCol) {
     dXstring::writeString(stream, m_name);
-    float min = (float)m_stats.min;
-    float max = (float)m_stats.max;
-    stream.write((char *)&min, sizeof(float));
-    stream.write((char *)&max, sizeof(float));
-    stream.write((char *)&m_stats.total, sizeof(m_stats.total));
-    stream.write((char *)&physicalCol, sizeof(int));
-    stream.write((char *)&m_hidden, sizeof(bool));
-    stream.write((char *)&m_locked, sizeof(bool));
-    stream.write((char *)&m_displayParams, sizeof(DisplayParams));
+    float min = (float)stats.min;
+    float max = (float)stats.max;
+    stream.write(reinterpret_cast<const char *>(&min), sizeof(float));
+    stream.write(reinterpret_cast<const char *>(&max), sizeof(float));
+    stream.write(reinterpret_cast<const char *>(&stats.total), sizeof(stats.total));
+    stream.write(reinterpret_cast<const char *>(&physicalCol), sizeof(int));
+    stream.write(reinterpret_cast<const char *>(&m_hidden), sizeof(bool));
+    stream.write(reinterpret_cast<const char *>(&m_locked), sizeof(bool));
+    stream.write(reinterpret_cast<const char *>(&m_displayParams), sizeof(DisplayParams));
     dXstring::writeString(stream, m_formula);
 }
 
@@ -122,12 +131,12 @@ void AttributeRowImpl::removeColumn(size_t index) {
 }
 
 void AttributeRowImpl::read(std::istream &stream) {
-    stream.read((char *)&m_layerKey, sizeof(m_layerKey));
+    stream.read(reinterpret_cast<char *>(&m_layerKey), sizeof(m_layerKey));
     dXreadwrite::readIntoVector(stream, m_data);
 }
 
 void AttributeRowImpl::write(std::ostream &stream) {
-    stream.write((char *)&m_layerKey, sizeof(m_layerKey));
+    stream.write(reinterpret_cast<const char *>(&m_layerKey), sizeof(m_layerKey));
     dXreadwrite::writeVector(stream, m_data);
 }
 
@@ -154,7 +163,7 @@ AttributeRow &AttributeRowImpl::incrValue(const std::string &colName, float valu
 
 AttributeRow &AttributeTable::getRow(const AttributeKey &key) {
     auto *row = getRowPtr(key);
-    if (row == 0) {
+    if (row == nullptr) {
         throw std::out_of_range("Invalid row key");
     }
     return *row;
@@ -162,7 +171,7 @@ AttributeRow &AttributeTable::getRow(const AttributeKey &key) {
 
 const AttributeRow &AttributeTable::getRow(const AttributeKey &key) const {
     auto *row = getRowPtr(key);
-    if (row == 0) {
+    if (row == nullptr) {
         throw std::out_of_range("Invalid row key");
     }
     return *row;
@@ -171,7 +180,7 @@ const AttributeRow &AttributeTable::getRow(const AttributeKey &key) const {
 AttributeRow *AttributeTable::getRowPtr(const AttributeKey &key) {
     auto iter = m_rows.find(key);
     if (iter == m_rows.end()) {
-        return 0;
+        return nullptr;
     }
     return iter->second.get();
 }
@@ -179,11 +188,19 @@ AttributeRow *AttributeTable::getRowPtr(const AttributeKey &key) {
 const AttributeRow *AttributeTable::getRowPtr(const AttributeKey &key) const {
     auto iter = m_rows.find(key);
     if (iter == m_rows.end()) {
-        return 0;
+        return nullptr;
     }
     return iter->second.get();
 }
 
+size_t AttributeTable::getRowIdx(const AttributeKey &key) const {
+    auto iter = m_rows.find(key);
+    if (iter == m_rows.end()) {
+        throw std::out_of_range("Invalid row key");
+    }
+    return static_cast<size_t>(std::distance(m_rows.begin(), iter));
+}
+
 AttributeRow &AttributeTable::addRow(const AttributeKey &key) {
     auto iter = m_rows.find(key);
     if (iter != m_rows.end()) {
@@ -218,7 +235,7 @@ size_t AttributeTable::insertOrResetColumn(const std::string &columnName,
     }
 
     // it exists - we need to reset it
-    m_columns[iter->second].m_stats = AttributeColumnStats();
+    m_columns[iter->second].stats = AttributeColumnStats();
     m_columns[iter->second].setLock(false);
     for (auto &row : m_rows) {
         row.second->setValue(iter->second, -1.0f);
@@ -286,7 +303,7 @@ void AttributeTable::setDisplayParamsForAllAttributes(const DisplayParams &param
 void AttributeTable::read(std::istream &stream, LayerManager &layerManager) {
     layerManager.read(stream);
     int colcount;
-    stream.read((char *)&colcount, sizeof(colcount));
+    stream.read(reinterpret_cast<char *>(&colcount), sizeof(colcount));
     std::map<size_t, AttributeColumnImpl> tmp;
     for (int j = 0; j < colcount; j++) {
         AttributeColumnImpl col("");
@@ -299,22 +316,22 @@ void AttributeTable::read(std::istream &stream, LayerManager &layerManager) {
     }
 
     int rowcount, rowkey;
-    stream.read((char *)&rowcount, sizeof(rowcount));
+    stream.read(reinterpret_cast<char *>(&rowcount), sizeof(rowcount));
     for (int i = 0; i < rowcount; i++) {
-        stream.read((char *)&rowkey, sizeof(rowkey));
+        stream.read(reinterpret_cast<char *>(&rowkey), sizeof(rowkey));
         auto row = std::unique_ptr<AttributeRowImpl>(new AttributeRowImpl(*this));
         row->read(stream);
         m_rows.insert(std::make_pair(AttributeKey(rowkey), std::move(row)));
     }
 
     // ref column display params
-    stream.read((char *)&m_displayParams, sizeof(DisplayParams));
+    stream.read(reinterpret_cast<char *>(&m_displayParams), sizeof(DisplayParams));
 }
 
 void AttributeTable::write(std::ostream &stream, const LayerManager &layerManager) {
     layerManager.write(stream);
     int colCount = (int)m_columns.size();
-    stream.write((char *)&colCount, sizeof(int));
+    stream.write(reinterpret_cast<const char *>(&colCount), sizeof(int));
 
     // TODO: For binary compatibility write the columns in alphabetical order
     // but the physical columns in the order inserted
@@ -330,7 +347,7 @@ void AttributeTable::write(std::ostream &stream, const LayerManager &layerManage
     }
 
     int rowcount = (int)m_rows.size();
-    stream.write((char *)&rowcount, sizeof(int));
+    stream.write(reinterpret_cast<const char *>(&rowcount), sizeof(int));
     for (auto &kvp : m_rows) {
         kvp.first.write(stream);
         kvp.second->write(stream);
