@@ -24,9 +24,9 @@ struct MetaGraph {
     FileProperties fileProperties;
     int version = -1;
 
-    MetaGraph(std::string name = "") {
-        this->name = name;
-        this->version = -1; // <- if unsaved, file version is -1
+    MetaGraph(std::string name = "") : name(name), version(-1) {
+
+        // <- if unsaved, file version is -1
     }
 
     void updateParentRegions(ShapeMap &shapeMap);
