@@ -24,22 +24,13 @@
 /////////////////////////////////////////////////////////////////////////////////
 
 PointMap::PointMap(const QtRegion &parentRegion, const std::string &name)
-    : AttributeMap(std::unique_ptr<AttributeTable>(new AttributeTable())),
-      m_parentRegion(&parentRegion), m_points(0, 0) {
-    m_name = name;
+    : AttributeMap(std::unique_ptr<AttributeTable>(new AttributeTable())), m_name(name),
+      m_parentRegion(&parentRegion), m_points(0, 0), m_filledPointCount(0), m_spacing(0.0),
+      m_initialised(false), m_blockedlines(false), m_processed(false), m_boundarygraph(false),
+      m_undocounter(0) {
 
     m_cols = 0;
     m_rows = 0;
-    m_filled_point_count = 0;
-
-    m_spacing = 0.0;
-
-    m_initialised = false;
-    m_blockedlines = false;
-    m_processed = false;
-    m_boundarygraph = false;
-
-    m_undocounter = 0;
 }
 
 void PointMap::copy(const PointMap &sourcemap, bool copypoints, bool copyattributes) {
@@ -49,7 +40,7 @@ void PointMap::copy(const PointMap &sourcemap, bool copypoints, bool copyattribu
 
     m_cols = sourcemap.getCols();
     m_rows = sourcemap.getRows();
-    m_filled_point_count = sourcemap.getFilledPointCount();
+    m_filledPointCount = sourcemap.getFilledPointCount();
 
     m_spacing = sourcemap.getSpacing();
 
@@ -61,11 +52,10 @@ void PointMap::copy(const PointMap &sourcemap, bool copypoints, bool copyattribu
     m_undocounter = sourcemap.m_undocounter;
 
     m_offset = sourcemap.m_offset;
-    m_bottom_left = sourcemap.m_bottom_left;
+    m_bottomLeft = sourcemap.m_bottomLeft;
 
     if (copypoints || copyattributes) {
         m_points = sourcemap.m_points;
-        m_hasIsovistAnalysis = sourcemap.m_hasIsovistAnalysis;
     }
     if (copyattributes) {
 
@@ -111,8 +101,8 @@ void PointMap::communicate(time_t &atime, Communicator *comm, size_t record) {
 bool PointMap::setGrid(double spacing, const Point2f &offset) {
     m_spacing = spacing;
     // note, the internal offset is the offset from the bottom left
-    double xoffset = fmod(m_parentRegion->bottom_left.x + offset.x, m_spacing);
-    double yoffset = fmod(m_parentRegion->bottom_left.y + offset.y, m_spacing);
+    double xoffset = fmod(m_parentRegion->bottomLeft.x + offset.x, m_spacing);
+    double yoffset = fmod(m_parentRegion->bottomLeft.y + offset.y, m_spacing);
     if (xoffset < m_spacing / 2.0)
         xoffset += m_spacing;
     if (xoffset > m_spacing / 2.0)
@@ -125,7 +115,7 @@ bool PointMap::setGrid(double spacing, const Point2f &offset) {
     m_offset = Point2f(-xoffset, -yoffset);
 
     if (m_points.size() != 0) {
-        m_filled_point_count = 0;
+        m_filledPointCount = 0;
     }
     m_undocounter = 0; // <- reset the undo counter... sorry... once you've done
                        // this you can't undo
@@ -134,13 +124,12 @@ bool PointMap::setGrid(double spacing, const Point2f &offset) {
     m_cols = static_cast<size_t>(floor((xoffset + m_parentRegion->width()) / m_spacing + 0.5) + 1);
     m_rows = static_cast<size_t>(floor((yoffset + m_parentRegion->height()) / m_spacing + 0.5) + 1);
 
-    m_bottom_left = Point2f(m_parentRegion->bottom_left.x + m_offset.x,
-                            m_parentRegion->bottom_left.y + m_offset.y);
+    m_bottomLeft = Point2f(m_parentRegion->bottomLeft.x + m_offset.x,
+                           m_parentRegion->bottomLeft.y + m_offset.y);
 
-    m_region =
-        QtRegion(Point2f(m_bottom_left.x - m_spacing / 2.0, m_bottom_left.y - m_spacing / 2.0),
-                 Point2f(m_bottom_left.x + double(m_cols - 1) * m_spacing + m_spacing / 2.0,
-                         m_bottom_left.y + double(m_rows - 1) * m_spacing + m_spacing / 2.0));
+    m_region = QtRegion(Point2f(m_bottomLeft.x - m_spacing / 2.0, m_bottomLeft.y - m_spacing / 2.0),
+                        Point2f(m_bottomLeft.x + double(m_cols - 1) * m_spacing + m_spacing / 2.0,
+                                m_bottomLeft.y + double(m_rows - 1) * m_spacing + m_spacing / 2.0));
 
     m_points = depthmapX::ColumnMatrix<Point>(m_rows, m_cols);
     for (size_t j = 0; j < m_cols; j++) {
@@ -155,7 +144,7 @@ bool PointMap::setGrid(double spacing, const Point2f &offset) {
     m_processed = false;
     m_boundarygraph = false;
 
-    m_merge_lines.clear();
+    m_mergeLines.clear();
 
     return true;
 }
@@ -166,13 +155,13 @@ bool PointMap::clearAllPoints() {
             point.set(Point::EMPTY, m_undocounter);
         }
     }
-    m_filled_point_count = 0;
-    m_merge_lines.clear();
+    m_filledPointCount = 0;
+    m_mergeLines.clear();
     return true;
 }
 
 bool PointMap::clearPointsInRange(PixelRef bl, PixelRef tr, std::set<int> &selSet) {
-    if (!m_filled_point_count) {
+    if (!m_filledPointCount) {
         return false;
     }
 
@@ -193,12 +182,12 @@ bool PointMap::clearPointsInRange(PixelRef bl, PixelRef tr, std::set<int> &selSe
                     PixelRef p = pnt.m_merge;
                     auto &point = getPoint(p);
                     depthmapX::findAndErase(
-                        m_merge_lines,
+                        m_mergeLines,
                         PixelRefPair(PixelRef(static_cast<short>(i), static_cast<short>(j)), p));
                     point.m_merge = NoPixel;
                     point.m_state &= ~Point::MERGED;
                 }
-                m_filled_point_count--;
+                m_filledPointCount--;
             }
         }
     }
@@ -211,19 +200,19 @@ bool PointMap::undoPoints() {
         return false;
     }
     for (auto &p : m_points) {
-        if (p.m_misc == m_undocounter) {
+        if (p.undoCounter == m_undocounter) {
             if (p.m_state & Point::FILLED) {
                 p.m_state &= ~Point::FILLED;
                 p.m_state |= Point::EMPTY;
-                p.m_misc = 0; // probably shouldn't set to 0 (can't undo)  Eventually
-                              // will implement 'redo' counter as well
-                m_filled_point_count--;
+                p.undoCounter = 0; // probably shouldn't set to 0 (can't undo)  Eventually
+                                   // will implement 'redo' counter as well
+                m_filledPointCount--;
             } else if (p.m_state & Point::EMPTY) {
                 p.m_state |= Point::FILLED;
                 p.m_state &= ~Point::EMPTY;
-                p.m_misc = 0; // probably shouldn't set to 0 (can't undo)  Eventually
-                              // will implement 'redo' counter as well
-                m_filled_point_count++;
+                p.undoCounter = 0; // probably shouldn't set to 0 (can't undo)  Eventually
+                                   // will implement 'redo' counter as well
+                m_filledPointCount++;
             }
         }
     }
@@ -238,8 +227,8 @@ PixelRef PointMap::pixelate(const Point2f &p, bool constrain, int scalefactor) c
     PixelRef ref;
 
     double spacing = m_spacing / double(scalefactor);
-    ref.x = static_cast<short>(floor((p.x - m_bottom_left.x + (m_spacing / 2.0)) / spacing));
-    ref.y = static_cast<short>(floor((p.y - m_bottom_left.y + (m_spacing / 2.0)) / spacing));
+    ref.x = static_cast<short>(floor((p.x - m_bottomLeft.x + (m_spacing / 2.0)) / spacing));
+    ref.y = static_cast<short>(floor((p.y - m_bottomLeft.y + (m_spacing / 2.0)) / spacing));
 
     if (constrain) {
         if (ref.x < 0)
@@ -262,14 +251,14 @@ void PointMap::addPointsInRegionToSet(const QtRegion &r, std::set<PixelRef> &sel
 
 std::set<PixelRef> PointMap::getPointsInRegion(const QtRegion &r) const {
     std::set<PixelRef> selSet;
-    auto s_bl = pixelate(r.bottom_left, true);
-    auto s_tr = pixelate(r.top_right, true);
+    auto sBl = pixelate(r.bottomLeft, true);
+    auto sTr = pixelate(r.topRight, true);
 
     int mask = 0;
     mask |= Point::FILLED;
 
-    for (auto i = s_bl.x; i <= s_tr.x; i++) {
-        for (auto j = s_bl.y; j <= s_tr.y; j++) {
+    for (auto i = sBl.x; i <= sTr.x; i++) {
+        for (auto j = sBl.y; j <= sTr.y; j++) {
             PixelRef ref(i, j);
             if (getPoint(ref).getState() & mask) {
                 selSet.insert(ref);
@@ -284,7 +273,7 @@ void PointMap::fillLine(const Line &li) {
     for (size_t j = 0; j < pixels.size(); j++) {
         if (getPoint(pixels[j]).empty()) {
             getPoint(pixels[j]).set(Point::FILLED, m_undocounter);
-            m_filled_point_count++;
+            m_filledPointCount++;
         }
     }
 }
@@ -367,10 +356,10 @@ bool PointMap::fillPoint(const Point2f &p, bool add) {
     }
     Point &pt = getPoint(pix);
     if (add && !pt.filled()) {
-        m_filled_point_count++;
+        m_filledPointCount++;
         pt.set(Point::FILLED, ++m_undocounter);
     } else if (!add && (pt.m_state & Point::FILLED)) {
-        m_filled_point_count--;
+        m_filledPointCount--;
         pt.set(Point::EMPTY, ++m_undocounter);
         if (pt.m_merge != NoPixel) {
             unmergePixel(pix);
@@ -384,7 +373,7 @@ bool PointMap::fillPoint(const Point2f &p, bool add) {
 // NB --- I've returned to original
 
 // AV TV // semifilled
-bool PointMap::makePoints(const Point2f &seed, int fill_type, Communicator *comm) {
+bool PointMap::makePoints(const Point2f &seed, int fillType, Communicator *comm) {
     if (!m_initialised || m_points.size() == 0) {
         return false;
     }
@@ -418,15 +407,15 @@ bool PointMap::makePoints(const Point2f &seed, int fill_type, Communicator *comm
     // int filltype = fill_type ? Point::FILLED | Point::CONTEXTFILLED :
     // Point::FILLED;
     int filltype;
-    if (fill_type == 0) // FULLFILL
+    if (fillType == 0) // FULLFILL
         filltype = Point::FILLED;
-    else if (fill_type == 1) // SEMIFILL
+    else if (fillType == 1) // SEMIFILL
         filltype = Point::FILLED | Point::CONTEXTFILLED;
     else // AUGMENT
         filltype = Point::AUGMENTED;
 
     getPoint(seedref).set(filltype, m_undocounter);
-    m_filled_point_count++;
+    m_filledPointCount++;
 
     // Now... start making lines:
     pflipper<PixelRefVector> surface;
@@ -491,7 +480,7 @@ int PointMap::expand(const PixelRef p1, const PixelRef p2, PixelRefVector &list,
         }
     }
     getPoint(p2).set(filltype, m_undocounter);
-    m_filled_point_count++;
+    m_filledPointCount++;
     list.push_back(p2);
 
     // 8 = success
@@ -520,9 +509,9 @@ void PointMap::outputMergeLines(std::ostream &stream, char delim) {
     stream << "x1" << delim << "y1" << delim << "x2" << delim << "y2" << std::endl;
 
     stream.precision(12);
-    for (size_t i = 0; i < m_merge_lines.size(); i++) {
+    for (size_t i = 0; i < m_mergeLines.size(); i++) {
 
-        Line li(depixelate(m_merge_lines[i].a), depixelate(m_merge_lines[i].b));
+        Line li(depixelate(m_mergeLines[i].a), depixelate(m_mergeLines[i].b));
 
         stream << li.start().x << delim << li.start().y << delim << li.end().x << delim
                << li.end().y << std::endl;
@@ -592,8 +581,8 @@ void PointMap::outputNet(std::ostream &netfile) {
     for (auto &iter : graph) {
         auto graphKey = iter.first;
         Point2f p = depixelate(graphKey);
-        p.x = offset.x + (p.x - m_region.bottom_left.x) / maxdim;
-        p.y = 1.0 - (offset.y + (p.y - m_region.bottom_left.y) / maxdim);
+        p.x = offset.x + (p.x - m_region.bottomLeft.x) / maxdim;
+        p.y = 1.0 - (offset.y + (p.y - m_region.bottomLeft.y) / maxdim);
         netfile << (j + 1) << " \"" << graphKey << "\" " << p.x << " " << p.y << std::endl;
         j++;
     }
@@ -760,7 +749,7 @@ bool PointMap::blockedAdjacent(const PixelRef p) const {
 bool PointMap::readMetadata(std::istream &stream) {
     m_name = dXstring::readString(stream);
 
-    stream.read((char *)&m_spacing, sizeof(m_spacing));
+    stream.read(reinterpret_cast<char *>(&m_spacing), sizeof(m_spacing));
 
     int rows, cols;
     stream.read(reinterpret_cast<char *>(&rows), sizeof(rows));
@@ -768,14 +757,13 @@ bool PointMap::readMetadata(std::istream &stream) {
     m_rows = static_cast<size_t>(rows);
     m_cols = static_cast<size_t>(cols);
 
-    stream.read((char *)&m_filled_point_count, sizeof(m_filled_point_count));
+    stream.read(reinterpret_cast<char *>(&m_filledPointCount), sizeof(m_filledPointCount));
 
-    stream.read((char *)&m_bottom_left, sizeof(m_bottom_left));
+    stream.read(reinterpret_cast<char *>(&m_bottomLeft), sizeof(m_bottomLeft));
 
-    m_region =
-        QtRegion(Point2f(m_bottom_left.x - m_spacing / 2.0, m_bottom_left.y - m_spacing / 2.0),
-                 Point2f(m_bottom_left.x + double(m_cols - 1) * m_spacing + m_spacing / 2.0,
-                         m_bottom_left.y + double(m_rows - 1) * m_spacing + m_spacing / 2.0));
+    m_region = QtRegion(Point2f(m_bottomLeft.x - m_spacing / 2.0, m_bottomLeft.y - m_spacing / 2.0),
+                        Point2f(m_bottomLeft.x + double(m_cols - 1) * m_spacing + m_spacing / 2.0,
+                                m_bottomLeft.y + double(m_rows - 1) * m_spacing + m_spacing / 2.0));
     return true;
 }
 
@@ -787,17 +775,6 @@ bool PointMap::readPointsAndAttributes(std::istream &stream) {
     for (size_t j = 0; j < m_cols; j++) {
         for (size_t k = 0; k < m_rows; k++) {
             m_points(k, j).read(stream);
-
-            // check if occdistance of any pixel's bin is set, meaning that
-            // the isovist analysis was done
-            if (!m_hasIsovistAnalysis) {
-                for (int b = 0; b < 32; b++) {
-                    if (m_points(k, j).m_node && m_points(k, j).m_node->occdistance(b) > 0) {
-                        m_hasIsovistAnalysis = true;
-                        break;
-                    }
-                }
-            }
         }
 
         for (size_t k = 0; k < m_rows; k++) {
@@ -816,7 +793,7 @@ bool PointMap::readPointsAndAttributes(std::istream &stream) {
             // Add merge line if merged:
             if (!pnt.m_merge.empty()) {
                 depthmapX::addIfNotExists(
-                    m_merge_lines,
+                    m_mergeLines,
                     PixelRefPair(PixelRef(static_cast<short>(j), static_cast<short>(k)),
                                  pnt.m_merge));
             }
@@ -826,8 +803,8 @@ bool PointMap::readPointsAndAttributes(std::istream &stream) {
     m_initialised = true;
     m_blockedlines = false;
 
-    stream.read((char *)&m_processed, sizeof(m_processed));
-    stream.read((char *)&m_boundarygraph, sizeof(m_boundarygraph));
+    stream.read(reinterpret_cast<char *>(&m_processed), sizeof(m_processed));
+    stream.read(reinterpret_cast<char *>(&m_boundarygraph), sizeof(m_boundarygraph));
     return true;
 }
 
@@ -838,7 +815,7 @@ std::tuple<bool, int> PointMap::read(std::istream &stream) {
     // instead construct another read/write function for a GUI using
     // the functions above and below
     int displayedAttribute;
-    stream.read((char *)&displayedAttribute, sizeof(displayedAttribute));
+    stream.read(reinterpret_cast<char *>(&displayedAttribute), sizeof(displayedAttribute));
 
     read = read && readPointsAndAttributes(stream);
 
@@ -848,16 +825,16 @@ std::tuple<bool, int> PointMap::read(std::istream &stream) {
 bool PointMap::writeMetadata(std::ostream &stream) const {
     dXstring::writeString(stream, m_name);
 
-    stream.write((char *)&m_spacing, sizeof(m_spacing));
+    stream.write(reinterpret_cast<const char *>(&m_spacing), sizeof(m_spacing));
 
     int rows = static_cast<int>(m_rows);
     int cols = static_cast<int>(m_cols);
     stream.write(reinterpret_cast<char *>(&rows), sizeof(rows));
     stream.write(reinterpret_cast<char *>(&cols), sizeof(cols));
 
-    stream.write((char *)&m_filled_point_count, sizeof(m_filled_point_count));
+    stream.write(reinterpret_cast<const char *>(&m_filledPointCount), sizeof(m_filledPointCount));
 
-    stream.write((char *)&m_bottom_left, sizeof(m_bottom_left));
+    stream.write(reinterpret_cast<const char *>(&m_bottomLeft), sizeof(m_bottomLeft));
     return true;
 }
 
@@ -869,15 +846,15 @@ bool PointMap::writePointsAndAttributes(std::ostream &stream) const {
         point.write(stream);
     }
 
-    stream.write((char *)&m_processed, sizeof(m_processed));
-    stream.write((char *)&m_boundarygraph, sizeof(m_boundarygraph));
+    stream.write(reinterpret_cast<const char *>(&m_processed), sizeof(m_processed));
+    stream.write(reinterpret_cast<const char *>(&m_boundarygraph), sizeof(m_boundarygraph));
     return true;
 }
 
 bool PointMap::write(std::ostream &stream, int displayedAttribute) const {
     bool written = writeMetadata(stream);
 
-    stream.write((char *)&displayedAttribute, sizeof(displayedAttribute));
+    stream.write(reinterpret_cast<const char *>(&displayedAttribute), sizeof(displayedAttribute));
 
     written = written && writePointsAndAttributes(stream);
     return written;
@@ -902,10 +879,10 @@ size_t PointMap::tagState(bool settag) {
             Point &pt = getPoint(curs);
             if (pt.filled()) {
                 if (settag) {
-                    pt.m_misc = static_cast<int>(count);
+                    //                    pt.m_misc = static_cast<int>(count);
                     pt.m_processflag = 0x00FF; // process all quadrants
                 } else {
-                    pt.m_misc = 0;
+                    //                    pt.m_misc = 0;
                     pt.m_processflag = 0x0000; // reset process flag
                 }
                 count++;
@@ -947,7 +924,7 @@ bool PointMap::sparkGraph2(Communicator *comm, bool boundarygraph, double maxdis
                 PixelRef curs = PixelRef(static_cast<short>(i), static_cast<short>(j));
                 if (getPoint(curs).filled() && !getPoint(curs).edge()) {
                     m_points(j, i).m_state &= ~Point::FILLED;
-                    m_filled_point_count--;
+                    m_filledPointCount--;
                 }
             }
         }
@@ -978,9 +955,10 @@ bool PointMap::sparkGraph2(Communicator *comm, bool boundarygraph, double maxdis
 
             PixelRef curs = PixelRef(static_cast<short>(i), static_cast<short>(j));
 
-            if (getPoint(curs).getState() & Point::FILLED) {
+            auto &point = getPoint(curs);
+            if (point.getState() & Point::FILLED) {
 
-                getPoint(curs).m_node = std::unique_ptr<Node>(new Node());
+                point.m_node = std::unique_ptr<Node>(new Node());
                 m_attributes->addRow(AttributeKey(curs));
 
                 sparkPixel2(curs, 1,
@@ -1039,7 +1017,7 @@ bool PointMap::unmake(bool removeLinks) {
                 if (removeLinks) {
                     pnt.m_merge = NoPixel;
                 }
-                pnt.m_grid_connections = 0;
+                pnt.m_gridConnections = 0;
                 pnt.m_node = nullptr;
                 pnt.m_lines.clear();
                 pnt.setBlock(false);
@@ -1050,7 +1028,7 @@ bool PointMap::unmake(bool removeLinks) {
     m_blockedlines = false;
 
     if (removeLinks) {
-        m_merge_lines.clear();
+        m_mergeLines.clear();
     }
 
     m_attributes->clear();
@@ -1067,14 +1045,14 @@ bool PointMap::unmake(bool removeLinks) {
 // processing
 
 bool PointMap::sparkPixel2(PixelRef curs, int make, double maxdist) {
-    static std::vector<PixelRef> bins_b[32];
-    static float far_bin_dists[32];
+    static std::vector<PixelRef> binsB[32];
+    static float farBinDists[32];
     for (int i = 0; i < 32; i++) {
-        far_bin_dists[i] = 0.0f;
+        farBinDists[i] = 0.0f;
     }
-    int neighbourhood_size = 0;
-    double total_dist = 0.0;
-    double total_dist_sqr = 0.0;
+    int neighbourhoodSize = 0;
+    double totalDist = 0.0;
+    double totalDistSqr = 0.0;
 
     Point2f centre0 = depixelate(curs);
 
@@ -1095,36 +1073,36 @@ bool PointMap::sparkPixel2(PixelRef curs, int make, double maxdist) {
         QtRegion viewport0 = regionate(curs, 1e-10);
         switch (q) {
         case 0:
-            viewport0.top_right.x = centre0.x;
-            viewport0.bottom_left.y = centre0.y - border;
+            viewport0.topRight.x = centre0.x;
+            viewport0.bottomLeft.y = centre0.y - border;
             break;
         case 6:
-            viewport0.top_right.x = centre0.x + border;
-            viewport0.bottom_left.y = centre0.y;
+            viewport0.topRight.x = centre0.x + border;
+            viewport0.bottomLeft.y = centre0.y;
             break;
         case 1:
-            viewport0.bottom_left.x = centre0.x;
-            viewport0.bottom_left.y = centre0.y - border;
+            viewport0.bottomLeft.x = centre0.x;
+            viewport0.bottomLeft.y = centre0.y - border;
             break;
         case 7:
-            viewport0.bottom_left.x = centre0.x - border;
-            viewport0.bottom_left.y = centre0.y;
+            viewport0.bottomLeft.x = centre0.x - border;
+            viewport0.bottomLeft.y = centre0.y;
             break;
         case 2:
-            viewport0.top_right.x = centre0.x;
-            viewport0.top_right.y = centre0.y + border;
+            viewport0.topRight.x = centre0.x;
+            viewport0.topRight.y = centre0.y + border;
             break;
         case 4:
-            viewport0.top_right.x = centre0.x + border;
-            viewport0.top_right.y = centre0.y;
+            viewport0.topRight.x = centre0.x + border;
+            viewport0.topRight.y = centre0.y;
             break;
         case 3:
-            viewport0.bottom_left.x = centre0.x;
-            viewport0.top_right.y = centre0.y + border;
+            viewport0.bottomLeft.x = centre0.x;
+            viewport0.topRight.y = centre0.y + border;
             break;
         case 5:
-            viewport0.bottom_left.x = centre0.x - border;
-            viewport0.top_right.y = centre0.y;
+            viewport0.bottomLeft.x = centre0.x - border;
+            viewport0.topRight.y = centre0.y;
             break;
         }
         std::vector<Line> lines0;
@@ -1153,15 +1131,15 @@ bool PointMap::sparkPixel2(PixelRef curs, int make, double maxdist) {
                         // the blocked cells shouldn't contribute to point stats
                         // note m_spacing is used to scale the moment of inertia
                         // appropriately
-                        double this_dist = dist(addlist[n], curs) * m_spacing;
-                        if (this_dist > far_bin_dists[bin]) {
-                            far_bin_dists[bin] = (float)this_dist;
+                        double thisDist = dist(addlist[n], curs) * m_spacing;
+                        if (thisDist > farBinDists[bin]) {
+                            farBinDists[bin] = (float)thisDist;
                         }
-                        total_dist += this_dist;
-                        total_dist_sqr += this_dist * this_dist;
-                        neighbourhood_size++;
+                        totalDist += thisDist;
+                        totalDistSqr += thisDist * thisDist;
+                        neighbourhoodSize++;
 
-                        bins_b[bin].push_back(addlist[n]);
+                        binsB[bin].push_back(addlist[n]);
                     }
                     if (make & 2) {
                         getPoint(addlist[n]).m_processflag |= q_opposite(bin);
@@ -1176,16 +1154,16 @@ bool PointMap::sparkPixel2(PixelRef curs, int make, double maxdist) {
     if (make & 1) {
         // The bins are cleared in the make function!
         Point &pt = getPoint(curs);
-        pt.m_node->make(curs, bins_b, far_bin_dists,
+        pt.m_node->make(curs, binsB, farBinDists,
                         pt.m_processflag); // note: make clears bins!
         AttributeRow &row = m_attributes->getRow(AttributeKey(curs));
-        row.setValue(PointMap::Column::CONNECTIVITY, float(neighbourhood_size));
-        row.setValue(PointMap::Column::POINT_FIRST_MOMENT, float(total_dist));
-        row.setValue(PointMap::Column::POINT_SECOND_MOMENT, float(total_dist_sqr));
+        row.setValue(PointMap::Column::CONNECTIVITY, float(neighbourhoodSize));
+        row.setValue(PointMap::Column::POINT_FIRST_MOMENT, float(totalDist));
+        row.setValue(PointMap::Column::POINT_SECOND_MOMENT, float(totalDistSqr));
     } else {
         // Clear bins by hand if not using them to make
         for (int i = 0; i < 32; i++) {
-            bins_b[i].clear();
+            binsB[i].clear();
         }
     }
 
@@ -1200,7 +1178,7 @@ bool PointMap::sieve2(sparkSieve2 &sieve, std::vector<PixelRef> &addlist, int q,
     bool hasgaps = false;
     int firstind = 0;
 
-    for (auto iter = sieve.m_gaps.begin(); iter != sieve.m_gaps.end(); ++iter) {
+    for (auto iter = sieve.gaps.begin(); iter != sieve.gaps.end(); ++iter) {
         // this goes through all open points
         if (iter->remove) {
             continue;
@@ -1256,7 +1234,7 @@ bool PointMap::sieve2(sparkSieve2 &sieve, std::vector<PixelRef> &addlist, int q,
 ////////////////////////////////////////////////////////////////////////////////////////////////
 
 bool PointMap::binDisplay(Communicator *, std::set<int> &selSet) {
-    auto bindisplay_col = m_attributes->insertOrResetColumn("Node Bins");
+    auto bindisplayCol = m_attributes->insertOrResetColumn("Node Bins");
 
     for (auto &sel : selSet) {
         Point &p = getPoint(sel);
@@ -1267,7 +1245,7 @@ bool PointMap::binDisplay(Communicator *, std::set<int> &selSet) {
             while (!b.is_tail()) {
                 // m_attributes->setValue( row, bindisplay_col, float((i % 8) + 1) );
                 m_attributes->getRow(AttributeKey(b.cursor()))
-                    .setValue(bindisplay_col, float(b.distance()));
+                    .setValue(bindisplayCol, float(b.distance()));
                 b.next();
             }
         }
@@ -1281,8 +1259,8 @@ bool PointMap::mergePoints(const Point2f &p, QtRegion &firstPointsBounds,
 
     // note that in a multiple selection, the point p is adjusted by the selection
     // bounds
-    PixelRef bl = pixelate(firstPointsBounds.bottom_left);
-    PixelRef tr = pixelate(firstPointsBounds.top_right);
+    PixelRef bl = pixelate(firstPointsBounds.bottomLeft);
+    PixelRef tr = pixelate(firstPointsBounds.topRight);
     //
     PixelRef offset = pixelate(p) - PixelRef(tr.x, bl.y);
     //
@@ -1312,7 +1290,7 @@ bool PointMap::unmergePoints(std::set<int> &firstPoints) {
 // Either of the pixels can be given here and the other will also be unmerged
 bool PointMap::unmergePixel(PixelRef a) {
     PixelRef c = getPoint(a).m_merge;
-    depthmapX::findAndErase(m_merge_lines, PixelRefPair(a, c));
+    depthmapX::findAndErase(m_mergeLines, PixelRefPair(a, c));
     getPoint(c).m_merge = NoPixel;
     getPoint(c).m_state &= ~Point::MERGED;
     getPoint(a).m_merge = NoPixel;
@@ -1327,17 +1305,17 @@ bool PointMap::mergePixels(PixelRef a, PixelRef b) {
     if (a != b && getPoint(a).m_merge != b) {
         if (!getPoint(a).m_merge.empty()) {
             PixelRef c = getPoint(a).m_merge;
-            auto it = std::find(m_merge_lines.begin(), m_merge_lines.end(), PixelRefPair(a, c));
-            if (it != m_merge_lines.end())
-                m_merge_lines.erase(it);
+            auto it = std::find(m_mergeLines.begin(), m_mergeLines.end(), PixelRefPair(a, c));
+            if (it != m_mergeLines.end())
+                m_mergeLines.erase(it);
             getPoint(c).m_merge = NoPixel;
             getPoint(c).m_state &= ~Point::MERGED;
         }
         if (!getPoint(b).m_merge.empty()) {
             PixelRef c = getPoint(b).m_merge;
-            auto it = std::find(m_merge_lines.begin(), m_merge_lines.end(), PixelRefPair(b, c));
-            if (it != m_merge_lines.end())
-                m_merge_lines.erase(it);
+            auto it = std::find(m_mergeLines.begin(), m_mergeLines.end(), PixelRefPair(b, c));
+            if (it != m_mergeLines.end())
+                m_mergeLines.erase(it);
             getPoint(c).m_merge = NoPixel;
             getPoint(c).m_state &= ~Point::MERGED;
         }
@@ -1345,7 +1323,7 @@ bool PointMap::mergePixels(PixelRef a, PixelRef b) {
         getPoint(a).m_state |= Point::MERGED;
         getPoint(b).m_merge = a;
         getPoint(b).m_state |= Point::MERGED;
-        m_merge_lines.push_back(PixelRefPair(a, b));
+        m_mergeLines.push_back(PixelRefPair(a, b));
     }
 
     // actually this return now triggers redraw whatever
@@ -1399,13 +1377,13 @@ void PointMap::addGridConnections() {
         PixelRef curs = iter->getKey().value;
         PixelRef node = curs.right();
         Point &point = getPoint(curs);
-        point.m_grid_connections = 0;
+        point.m_gridConnections = 0;
         for (int i = 0; i < 32; i += 4) {
             Bin &bin = point.m_node->bin(i);
             bin.first();
             while (!bin.is_tail()) {
                 if (node == bin.cursor()) {
-                    point.m_grid_connections |= (1 << (i / 4));
+                    point.m_gridConnections |= (1 << (i / 4));
                     break;
                 }
                 bin.next();
