@@ -9,7 +9,17 @@
 #include "salalib/isegment.h"
 
 class SegmentMetricPD : ISegment {
+
+    std::set<int> &m_originRefs;
+
   public:
+    struct Column {
+        inline static const std::string              //
+            METRIC_STEP_DEPTH = "Metric Step Depth"; //
+    };
+
+  public:
+    SegmentMetricPD(std::set<int> &originRefs) : m_originRefs(originRefs) {}
     std::string getAnalysisName() const override { return "Metric Analysis"; }
     AnalysisResult run(Communicator *, ShapeGraph &map, bool) override;
 };
