@@ -12,9 +12,18 @@
 class SegmentTopologicalShortestPath : public IAnalysis {
   private:
     ShapeGraph &m_map;
+    int m_refFrom, m_refTo;
 
   public:
-    SegmentTopologicalShortestPath(ShapeGraph &map) : m_map(map) {}
+    struct Column {
+        inline static const std::string                                          //
+            TOPOLOGICAL_SHORTEST_PATH_DEPTH = "Topological Shortest Path Depth", //
+            TOPOLOGICAL_SHORTEST_PATH_ORDER = "Topological Shortest Path Order"; //
+    };
+
+  public:
+    SegmentTopologicalShortestPath(ShapeGraph &map, int refFrom, int refTo)
+        : m_map(map), m_refFrom(refFrom), m_refTo(refTo) {}
     std::string getAnalysisName() const override { return "Topological Shortest Path"; }
     AnalysisResult run(Communicator *) override;
 };
