@@ -6,15 +6,15 @@
 
 #pragma once
 
-#include "salalib/ivga.h"
+#include "ivgaangular.h"
 #include "salalib/pointmap.h"
 
 #include "genlib/stringutils.h"
 
-class VGAAngular : IVGA {
+class VGAAngular : public IVGAAngular {
   private:
     double m_radius;
-    bool m_gates_only;
+    bool m_gatesOnly;
 
   public:
     struct Column {
@@ -37,7 +37,8 @@ class VGAAngular : IVGA {
     }
 
   public:
+    VGAAngular(const PointMap &map, double radius, bool gatesOnly)
+        : IVGAAngular(map), m_radius(radius), m_gatesOnly(gatesOnly) {}
     std::string getAnalysisName() const override { return "Angular Analysis"; }
-    AnalysisResult run(Communicator *, PointMap &map, bool) override;
-    VGAAngular(double radius, bool gates_only) : m_radius(radius), m_gates_only(gates_only) {}
+    AnalysisResult run(Communicator *comm) override;
 };
