@@ -13,11 +13,14 @@
 class VGAVisualLocalOpenMP : public IAnalysis {
   private:
     PointMap &m_map;
+    std::optional<int> m_limitToThreads;
+    bool m_forceCommUpdatesMasterThread = false;
+
     struct DataPoint {
         float cluster, control, controllability;
     };
 
-    void dumpNeighbourhood(Node &node, std::set<PixelRef> &hood) const;
+    std::set<PixelRef> getNeighbourhood(const Node &node) const;
 
   public:
     struct Column {
@@ -28,7 +31,10 @@ class VGAVisualLocalOpenMP : public IAnalysis {
     };
 
   public:
-    VGAVisualLocalOpenMP(PointMap &map) : m_map(map) {}
+    VGAVisualLocalOpenMP(PointMap &map, std::optional<int> limitToThreads = std::nullopt,
+                         bool forceCommUpdatesMasterThread = false)
+        : m_map(map), m_limitToThreads(limitToThreads),
+          m_forceCommUpdatesMasterThread(forceCommUpdatesMasterThread) {}
     std::string getAnalysisName() const override { return "Local Visibility Analysis (OpenMP)"; }
     AnalysisResult run(Communicator *comm) override;
 };
